==> vertx-sql-common-3.5.0-sources.jar: io/vertx/groovy/ext/sql/SQLOperations_GroovyExtension.java <==
package io.vertx.groovy.ext.sql;
public class SQLOperations_GroovyExtension {
  public static io.vertx.ext.sql.SQLOperations query(io.vertx.ext.sql.SQLOperations j_receiver, java.lang.String sql, io.vertx.core.Handler<io.vertx.core.AsyncResult<java.util.Map<String, Object>>> resultHandler) {
    io.vertx.core.impl.ConversionHelper.fromObject(j_receiver.query(sql,
      resultHandler != null ? new io.vertx.core.Handler<io.vertx.core.AsyncResult<io.vertx.ext.sql.ResultSet>>() {
      public void handle(io.vertx.core.AsyncResult<io.vertx.ext.sql.ResultSet> ar) {
        resultHandler.handle(ar.map(event -> event != null ? io.vertx.core.impl.ConversionHelper.fromJsonObject(event.toJson()) : null));
      }
    } : null));
    return j_receiver;
  }
  public static io.vertx.ext.sql.SQLOperations queryWithParams(io.vertx.ext.sql.SQLOperations j_receiver, java.lang.String sql, java.util.List<Object> params, io.vertx.core.Handler<io.vertx.core.AsyncResult<java.util.Map<String, Object>>> resultHandler) {
    io.vertx.core.impl.ConversionHelper.fromObject(j_receiver.queryWithParams(sql,
      params != null ? io.vertx.core.impl.ConversionHelper.toJsonArray(params) : null,
      resultHandler != null ? new io.vertx.core.Handler<io.vertx.core.AsyncResult<io.vertx.ext.sql.ResultSet>>() {
      public void handle(io.vertx.core.AsyncResult<io.vertx.ext.sql.ResultSet> ar) {
        resultHandler.handle(ar.map(event -> event != null ? io.vertx.core.impl.ConversionHelper.fromJsonObject(event.toJson()) : null));
      }
    } : null));
    return j_receiver;
  }
  public static io.vertx.ext.sql.SQLOperations querySingle(io.vertx.ext.sql.SQLOperations j_receiver, java.lang.String sql, io.vertx.core.Handler<io.vertx.core.AsyncResult<java.util.List<Object>>> handler) {
    io.vertx.core.impl.ConversionHelper.fromObject(j_receiver.querySingle(sql,
      handler != null ? new io.vertx.core.Handler<io.vertx.core.AsyncResult<io.vertx.core.json.JsonArray>>() {
      public void handle(io.vertx.core.AsyncResult<io.vertx.core.json.JsonArray> ar) {
        handler.handle(ar.map(event -> io.vertx.core.impl.ConversionHelper.fromJsonArray(event)));
      }
    } : null));
    return j_receiver;
  }
  public static io.vertx.ext.sql.SQLOperations querySingleWithParams(io.vertx.ext.sql.SQLOperations j_receiver, java.lang.String sql, java.util.List<Object> arguments, io.vertx.core.Handler<io.vertx.core.AsyncResult<java.util.List<Object>>> handler) {
    io.vertx.core.impl.ConversionHelper.fromObject(j_receiver.querySingleWithParams(sql,
      arguments != null ? io.vertx.core.impl.ConversionHelper.toJsonArray(arguments) : null,
      handler != null ? new io.vertx.core.Handler<io.vertx.core.AsyncResult<io.vertx.core.json.JsonArray>>() {
      public void handle(io.vertx.core.AsyncResult<io.vertx.core.json.JsonArray> ar) {
        handler.handle(ar.map(event -> io.vertx.core.impl.ConversionHelper.fromJsonArray(event)));
      }
    } : null));
    return j_receiver;
  }
  public static io.vertx.ext.sql.SQLOperations update(io.vertx.ext.sql.SQLOperations j_receiver, java.lang.String sql, io.vertx.core.Handler<io.vertx.core.AsyncResult<java.util.Map<String, Object>>> resultHandler) {
    io.vertx.core.impl.ConversionHelper.fromObject(j_receiver.update(sql,
      resultHandler != null ? new io.vertx.core.Handler<io.vertx.core.AsyncResult<io.vertx.ext.sql.UpdateResult>>() {
      public void handle(io.vertx.core.AsyncResult<io.vertx.ext.sql.UpdateResult> ar) {
        resultHandler.handle(ar.map(event -> event != null ? io.vertx.core.impl.ConversionHelper.fromJsonObject(event.toJson()) : null));
      }
    } : null));
    return j_receiver;
  }
  public static io.vertx.ext.sql.SQLOperations updateWithParams(io.vertx.ext.sql.SQLOperations j_receiver, java.lang.String sql, java.util.List<Object> params, io.vertx.core.Handler<io.vertx.core.AsyncResult<java.util.Map<String, Object>>> resultHandler) {
    io.vertx.core.impl.ConversionHelper.fromObject(j_receiver.updateWithParams(sql,
      params != null ? io.vertx.core.impl.ConversionHelper.toJsonArray(params) : null,
      resultHandler != null ? new io.vertx.core.Handler<io.vertx.core.AsyncResult<io.vertx.ext.sql.UpdateResult>>() {
      public void handle(io.vertx.core.AsyncResult<io.vertx.ext.sql.UpdateResult> ar) {
        resultHandler.handle(ar.map(event -> event != null ? io.vertx.core.impl.ConversionHelper.fromJsonObject(event.toJson()) : null));
      }
    } : null));
    return j_receiver;
  }
}

==> vertx-sql-common-3.5.1-sources.jar: io/vertx/groovy/ext/sql/SQLOperations_GroovyExtension.java <==
package io.vertx.groovy.ext.sql;
public class SQLOperations_GroovyExtension {
  public static io.vertx.ext.sql.SQLOperations query(io.vertx.ext.sql.SQLOperations j_receiver, java.lang.String sql, io.vertx.core.Handler<io.vertx.core.AsyncResult<java.util.Map<String, Object>>> resultHandler) {
    io.vertx.core.impl.ConversionHelper.fromObject(j_receiver.query(sql,
      resultHandler != null ? new io.vertx.core.Handler<io.vertx.core.AsyncResult<io.vertx.ext.sql.ResultSet>>() {
      public void handle(io.vertx.core.AsyncResult<io.vertx.ext.sql.ResultSet> ar) {
        resultHandler.handle(ar.map(event -> event != null ? io.vertx.core.impl.ConversionHelper.fromJsonObject(event.toJson()) : null));
      }
    } : null));
    return j_receiver;
  }
  public static io.vertx.ext.sql.SQLOperations queryWithParams(io.vertx.ext.sql.SQLOperations j_receiver, java.lang.String sql, java.util.List<Object> params, io.vertx.core.Handler<io.vertx.core.AsyncResult<java.util.Map<String, Object>>> resultHandler) {
    io.vertx.core.impl.ConversionHelper.fromObject(j_receiver.queryWithParams(sql,
      params != null ? io.vertx.core.impl.ConversionHelper.toJsonArray(params) : null,
      resultHandler != null ? new io.vertx.core.Handler<io.vertx.core.AsyncResult<io.vertx.ext.sql.ResultSet>>() {
      public void handle(io.vertx.core.AsyncResult<io.vertx.ext.sql.ResultSet> ar) {
        resultHandler.handle(ar.map(event -> event != null ? io.vertx.core.impl.ConversionHelper.fromJsonObject(event.toJson()) : null));
      }
    } : null));
    return j_receiver;
  }
  public static io.vertx.ext.sql.SQLOperations querySingle(io.vertx.ext.sql.SQLOperations j_receiver, java.lang.String sql, io.vertx.core.Handler<io.vertx.core.AsyncResult<java.util.List<Object>>> handler) {
    io.vertx.core.impl.ConversionHelper.fromObject(j_receiver.querySingle(sql,
      handler != null ? new io.vertx.core.Handler<io.vertx.core.AsyncResult<io.vertx.core.json.JsonArray>>() {
      public void handle(io.vertx.core.AsyncResult<io.vertx.core.json.JsonArray> ar) {
        handler.handle(ar.map(event -> io.vertx.core.impl.ConversionHelper.fromJsonArray(event)));
      }
    } : null));
    return j_receiver;
  }
  public static io.vertx.ext.sql.SQLOperations querySingleWithParams(io.vertx.ext.sql.SQLOperations j_receiver, java.lang.String sql, java.util.List<Object> arguments, io.vertx.core.Handler<io.vertx.core.AsyncResult<java.util.List<Object>>> handler) {
    io.vertx.core.impl.ConversionHelper.fromObject(j_receiver.querySingleWithParams(sql,
      arguments != null ? io.vertx.core.impl.ConversionHelper.toJsonArray(arguments) : null,
      handler != null ? new io.vertx.core.Handler<io.vertx.core.AsyncResult<io.vertx.core.json.JsonArray>>() {
      public void handle(io.vertx.core.AsyncResult<io.vertx.core.json.JsonArray> ar) {
        handler.handle(ar.map(event -> io.vertx.core.impl.ConversionHelper.fromJsonArray(event)));
      }
    } : null));
    return j_receiver;
  }
  public static io.vertx.ext.sql.SQLOperations update(io.vertx.ext.sql.SQLOperations j_receiver, java.lang.String sql, io.vertx.core.Handler<io.vertx.core.AsyncResult<java.util.Map<String, Object>>> resultHandler) {
    io.vertx.core.impl.ConversionHelper.fromObject(j_receiver.update(sql,
      resultHandler != null ? new io.vertx.core.Handler<io.vertx.core.AsyncResult<io.vertx.ext.sql.UpdateResult>>() {
      public void handle(io.vertx.core.AsyncResult<io.vertx.ext.sql.UpdateResult> ar) {
        resultHandler.handle(ar.map(event -> event != null ? io.vertx.core.impl.ConversionHelper.fromJsonObject(event.toJson()) : null));
      }
    } : null));
    return j_receiver;
  }
  public static io.vertx.ext.sql.SQLOperations updateWithParams(io.vertx.ext.sql.SQLOperations j_receiver, java.lang.String sql, java.util.List<Object> params, io.vertx.core.Handler<io.vertx.core.AsyncResult<java.util.Map<String, Object>>> resultHandler) {
    io.vertx.core.impl.ConversionHelper.fromObject(j_receiver.updateWithParams(sql,
      params != null ? io.vertx.core.impl.ConversionHelper.toJsonArray(params) : null,
      resultHandler != null ? new io.vertx.core.Handler<io.vertx.core.AsyncResult<io.vertx.ext.sql.UpdateResult>>() {
      public void handle(io.vertx.core.AsyncResult<io.vertx.ext.sql.UpdateResult> ar) {
        resultHandler.handle(ar.map(event -> event != null ? io.vertx.core.impl.ConversionHelper.fromJsonObject(event.toJson()) : null));
      }
    } : null));
    return j_receiver;
  }
  public static io.vertx.ext.sql.SQLOperations call(io.vertx.ext.sql.SQLOperations j_receiver, java.lang.String sql, io.vertx.core.Handler<io.vertx.core.AsyncResult<java.util.Map<String, Object>>> resultHandler) {
    io.vertx.core.impl.ConversionHelper.fromObject(j_receiver.call(sql,
      resultHandler != null ? new io.vertx.core.Handler<io.vertx.core.AsyncResult<io.vertx.ext.sql.ResultSet>>() {
      public void handle(io.vertx.core.AsyncResult<io.vertx.ext.sql.ResultSet> ar) {
        resultHandler.handle(ar.map(event -> event != null ? io.vertx.core.impl.ConversionHelper.fromJsonObject(event.toJson()) : null));
      }
    } : null));
    return j_receiver;
  }
  public static io.vertx.ext.sql.SQLOperations callWithParams(io.vertx.ext.sql.SQLOperations j_receiver, java.lang.String sql, java.util.List<Object> params, java.util.List<Object> outputs, io.vertx.core.Handler<io.vertx.core.AsyncResult<java.util.Map<String, Object>>> resultHandler) {
    io.vertx.core.impl.ConversionHelper.fromObject(j_receiver.callWithParams(sql,
      params != null ? io.vertx.core.impl.ConversionHelper.toJsonArray(params) : null,
      outputs != null ? io.vertx.core.impl.ConversionHelper.toJsonArray(outputs) : null,
      resultHandler != null ? new io.vertx.core.Handler<io.vertx.core.AsyncResult<io.vertx.ext.sql.ResultSet>>() {
      public void handle(io.vertx.core.AsyncResult<io.vertx.ext.sql.ResultSet> ar) {
        resultHandler.handle(ar.map(event -> event != null ? io.vertx.core.impl.ConversionHelper.fromJsonObject(event.toJson()) : null));
      }
    } : null));
    return j_receiver;
  }
}
